export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    /**
     * The `DateTime` scalar type represents a DateTime
     * value as specified by
     * [iso8601](https://en.wikipedia.org/wiki/ISO_8601).
     */
    DateTime: any;
    /**
     * Allows use of a JSON String for input / output from the GraphQL schema.
     *
     * Use of this type is *not recommended* as you lose the benefits of having a defined, static
     * schema (one of the key benefits of GraphQL).
     */
    JSONString: any;
    /**
     * The `GenericScalar` scalar type represents a generic
     * GraphQL scalar value that could be:
     * String, Boolean, Int, Float, List or Object.
     */
    GenericScalar: any;
    /**
     * The `Date` scalar type represents a Date
     * value as specified by
     * [iso8601](https://en.wikipedia.org/wiki/ISO_8601).
     */
    Date: any;
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type Query = {
    __typename?: 'Query';
    auth0Profile?: Maybe<Auth0Profile>;
    mqlServerUrl?: Maybe<Scalars['String']>;
    latestMqlServer?: Maybe<ServiceRelease>;
    latestAvaticaServer?: Maybe<ServiceRelease>;
    myOrganization?: Maybe<Organization>;
    myUser?: Maybe<User>;
    allFeatures?: Maybe<Array<Maybe<Feature>>>;
    allOrganizations?: Maybe<Array<Maybe<Organization>>>;
    totalFeatures?: Maybe<Scalars['Int']>;
    totalOrganizations?: Maybe<Scalars['Int']>;
    organizationTest?: Maybe<Organization>;
    featureTest?: Maybe<Feature>;
    allMetricFilters?: Maybe<Scalars['GenericScalar']>;
    boom?: Maybe<Scalars['Boolean']>;
    transformConfig?: Maybe<TransformConfig>;
    emailCanSignUp?: Maybe<Scalars['Boolean']>;
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryAuth0ProfileArgs = {
    auth0Id: Scalars['String'];
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryAllFeaturesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<FeatureStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<FeatureOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryAllOrganizationsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<OrganizationStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<OrganizationOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryOrganizationTestArgs = {
    id: Scalars['ID'];
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryFeatureTestArgs = {
    id: Scalars['ID'];
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryBoomArgs = {
    raise_?: Maybe<Scalars['Boolean']>;
};
/**
 * Base Query object exposed by GraphQL.
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryEmailCanSignUpArgs = {
    email: Scalars['String'];
};
/** A wrapper for the response we get from Auth0's user profile API */
export declare type Auth0Profile = {
    __typename?: 'Auth0Profile';
    picture?: Maybe<Scalars['String']>;
    lastIp?: Maybe<Scalars['String']>;
    lastLogin?: Maybe<Scalars['DateTime']>;
    loginsCount?: Maybe<Scalars['Int']>;
    blocked?: Maybe<Scalars['Boolean']>;
    emailVerified?: Maybe<Scalars['Boolean']>;
};
/**
 * This is the externally-facing Graphene object representing the available MQL server download.
 *
 * TODO: There's likely a simple way to merge these two objects together
 */
export declare type ServiceRelease = {
    __typename?: 'ServiceRelease';
    serviceName?: Maybe<Scalars['String']>;
    version?: Maybe<Scalars['String']>;
    downloadUrl?: Maybe<Scalars['String']>;
    versionHash?: Maybe<Scalars['String']>;
};
export declare type Organization = {
    __typename?: 'Organization';
    id: Scalars['ID'];
    name: Scalars['String'];
    logoUrl?: Maybe<Scalars['String']>;
    primaryConfigRepo?: Maybe<Scalars['String']>;
    primaryConfigBranch?: Maybe<Scalars['String']>;
    sourceControlUrl?: Maybe<Scalars['String']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deactivatedAt?: Maybe<Scalars['DateTime']>;
    mqlServerLogs?: Maybe<Scalars['String']>;
    isHosted: Scalars['Boolean'];
    type?: Maybe<OrgType>;
    users?: Maybe<Array<Maybe<User>>>;
    mqlServers?: Maybe<Array<Maybe<OrgMqlServer>>>;
    models?: Maybe<Array<Maybe<Model>>>;
    orgMetrics?: Maybe<Array<Maybe<OrgMetric>>>;
    mqlHeartbeats?: Maybe<Array<Maybe<MqlHeartbeat>>>;
    currentModel?: Maybe<Array<Maybe<Model>>>;
    teams?: Maybe<Array<Maybe<Team>>>;
    apiKeys?: Maybe<Array<Maybe<ApiKey>>>;
    metricViews?: Maybe<Array<Maybe<MetricView>>>;
    savedQueries?: Maybe<Array<Maybe<SavedQuery>>>;
    teamViews?: Maybe<Array<Maybe<TeamView>>>;
    dashboards?: Maybe<Array<Maybe<Dashboard>>>;
    metricCollections?: Maybe<Array<Maybe<MetricCollection>>>;
    questions?: Maybe<Array<Maybe<Question>>>;
    question?: Maybe<Question>;
    annotations?: Maybe<Array<Maybe<Annotation>>>;
    recentQuestions?: Maybe<Array<Maybe<Question>>>;
    recentAnnotations?: Maybe<Array<Maybe<Annotation>>>;
    totalQuestions?: Maybe<Scalars['Int']>;
    totalAnnotations?: Maybe<Scalars['Int']>;
    metrics?: Maybe<Array<Maybe<Metric>>>;
    totalMetrics?: Maybe<Scalars['Int']>;
    latestMqlHeartbeat?: Maybe<MqlHeartbeat>;
    totalUsers?: Maybe<Scalars['Int']>;
    totalTeams?: Maybe<Scalars['Int']>;
    mqlServer?: Maybe<OrgMqlServer>;
    totalMqlServers?: Maybe<Scalars['Int']>;
    metric?: Maybe<Metric>;
    team?: Maybe<Team>;
    dashboard?: Maybe<Dashboard>;
    savedQuery?: Maybe<SavedQuery>;
    metricCollection?: Maybe<MetricCollection>;
    totalMetricCollections?: Maybe<Scalars['Int']>;
    totalSavedQueries?: Maybe<Scalars['Int']>;
    totalActiveFeatures?: Maybe<Scalars['Int']>;
    requireMfa?: Maybe<Scalars['Boolean']>;
    allowMfaRememberBrowser?: Maybe<Scalars['Boolean']>;
    mqlServerUrl?: Maybe<Scalars['String']>;
    allowedEmailDomains?: Maybe<Array<Maybe<Scalars['String']>>>;
    tierTooltips?: Maybe<Scalars['GenericScalar']>;
    activeFeatures?: Maybe<Array<Maybe<Feature>>>;
};
export declare type OrganizationUsersArgs = {
    activeOnly?: Maybe<Scalars['Boolean']>;
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<UserStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<UserOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationMqlServersArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<OrgMqlServerStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<OrgMqlServerOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationModelsArgs = {
    id?: Maybe<Scalars['ID']>;
};
export declare type OrganizationTeamsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<TeamStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<TeamOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationSavedQueriesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<SavedQueryStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<SavedQueryOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationMetricCollectionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricCollectionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationQuestionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<QuestionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<QuestionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationQuestionArgs = {
    id: Scalars['ID'];
};
export declare type OrganizationAnnotationsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<AnnotationStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<AnnotationOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationRecentQuestionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<QuestionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<QuestionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationRecentAnnotationsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<AnnotationStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<AnnotationOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationMetricsArgs = {
    names?: Maybe<Array<Maybe<Scalars['String']>>>;
    tiers?: Maybe<Array<Maybe<MetricTier>>>;
    types?: Maybe<Array<Maybe<MetricType>>>;
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type OrganizationTotalMetricsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    names?: Maybe<Array<Maybe<Scalars['String']>>>;
    tiers?: Maybe<Array<Maybe<MetricTier>>>;
    types?: Maybe<Array<Maybe<MetricType>>>;
};
export declare type OrganizationMqlServerArgs = {
    id: Scalars['ID'];
};
export declare type OrganizationMetricArgs = {
    name: Scalars['String'];
};
export declare type OrganizationTeamArgs = {
    slug: Scalars['String'];
};
export declare type OrganizationDashboardArgs = {
    id: Scalars['ID'];
};
export declare type OrganizationSavedQueryArgs = {
    id: Scalars['ID'];
};
export declare type OrganizationMetricCollectionArgs = {
    slug: Scalars['String'];
};
export declare type OrganizationTierTooltipsArgs = {
    tiers: Array<Maybe<Scalars['Int']>>;
};
/** An enumeration. */
export declare enum OrgType {
    Paid = "PAID",
    Trial = "TRIAL",
    Internal = "INTERNAL",
    Test = "TEST"
}
export declare type User = {
    __typename?: 'User';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    auth0Id: Scalars['String'];
    userName: Scalars['String'];
    email: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deactivatedAt?: Maybe<Scalars['DateTime']>;
    avatarUrl?: Maybe<Scalars['String']>;
    primaryDashboardId?: Maybe<Scalars['Int']>;
    roles?: Maybe<Array<Maybe<UserRole>>>;
    prefs?: Maybe<Array<Maybe<UserPref>>>;
    activeUserRoles?: Maybe<Array<Maybe<UserRole>>>;
    teams?: Maybe<Array<Maybe<Team>>>;
    teamMemberships?: Maybe<Array<Maybe<TeamMember>>>;
    dashboards?: Maybe<Array<Maybe<Dashboard>>>;
    primaryDashboard?: Maybe<Dashboard>;
    apiKeys?: Maybe<Array<Maybe<ApiKey>>>;
    savedQueries?: Maybe<Array<Maybe<SavedQuery>>>;
    organization?: Maybe<Organization>;
    teamViews?: Maybe<Array<Maybe<TeamView>>>;
    metricCollections?: Maybe<Array<Maybe<MetricCollection>>>;
    mqlServerUrl?: Maybe<Scalars['String']>;
    activeRoles?: Maybe<Array<Maybe<Scalars['String']>>>;
    isAdmin?: Maybe<Scalars['Boolean']>;
    isOrgAdmin?: Maybe<Scalars['Boolean']>;
    auth0Profile?: Maybe<Auth0Profile>;
    totalTeams?: Maybe<Scalars['Int']>;
    totalApiKeys?: Maybe<Scalars['Int']>;
    totalSavedQueries?: Maybe<Scalars['Int']>;
    totalViewedMetrics?: Maybe<Scalars['Int']>;
    totalMetricCollections?: Maybe<Scalars['Int']>;
    viewedTeams?: Maybe<Array<Maybe<Team>>>;
    totalViewedTeams?: Maybe<Scalars['Int']>;
    viewedMetricCollections?: Maybe<Array<Maybe<MetricCollection>>>;
    totalViewedMetricCollections?: Maybe<Scalars['Int']>;
    totalActiveFeatures?: Maybe<Scalars['Int']>;
    hasAcceptedLatestTermsOfService?: Maybe<Scalars['Boolean']>;
    viewedMetrics?: Maybe<Array<Maybe<Metric>>>;
    newMetrics?: Maybe<Array<Maybe<Metric>>>;
    activeFeatures?: Maybe<Array<Maybe<Feature>>>;
};
export declare type UserTeamsArgs = {
    isAdminOnly?: Maybe<Scalars['Boolean']>;
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<TeamStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<TeamOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserApiKeysArgs = {
    activeOnly?: Maybe<Scalars['Boolean']>;
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<ApiKeyStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<ApiKeyOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserSavedQueriesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<SavedQueryStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<SavedQueryOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserMetricCollectionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricCollectionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserViewedTeamsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<TeamStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<TeamOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserViewedMetricCollectionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricCollectionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserViewedMetricsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserNewMetricsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type UserRole = {
    __typename?: 'UserRole';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    userId: Scalars['Int'];
    role: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    removedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    user?: Maybe<User>;
};
export declare type UserPref = {
    __typename?: 'UserPref';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    userId: Scalars['Int'];
    prefKey: Scalars['String'];
    prefValue: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    user?: Maybe<User>;
};
export declare type Team = {
    __typename?: 'Team';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    name: Scalars['String'];
    createdBy?: Maybe<Scalars['Int']>;
    slug: Scalars['String'];
    theme?: Maybe<Scalars['String']>;
    primaryDashboardId?: Maybe<Scalars['Int']>;
    featuredMetricCollectionId?: Maybe<Scalars['Int']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deactivatedAt?: Maybe<Scalars['DateTime']>;
    description?: Maybe<Scalars['String']>;
    createdByUser?: Maybe<User>;
    organization?: Maybe<Organization>;
    members?: Maybe<Array<Maybe<TeamMember>>>;
    adminMembers?: Maybe<Array<Maybe<TeamMember>>>;
    memberUsers?: Maybe<Array<Maybe<User>>>;
    dashboards?: Maybe<Array<Maybe<Dashboard>>>;
    primaryDashboard?: Maybe<Dashboard>;
    featuredMetricCollection?: Maybe<MetricCollection>;
    savedQueries?: Maybe<Array<Maybe<SavedQuery>>>;
    views?: Maybe<Array<Maybe<TeamView>>>;
    metricCollections?: Maybe<Array<Maybe<MetricCollection>>>;
    teamAdminIds?: Maybe<Array<Maybe<Scalars['Int']>>>;
    userIsTeamAdmin?: Maybe<Scalars['Boolean']>;
    totalMetrics?: Maybe<Scalars['Int']>;
    totalSavedQueries?: Maybe<Scalars['Int']>;
    totalMetricCollections?: Maybe<Scalars['Int']>;
    totalMembers?: Maybe<Scalars['Int']>;
    totalRecentViews?: Maybe<Scalars['Int']>;
    totalRecentViewsForUser?: Maybe<Scalars['Int']>;
    metrics?: Maybe<Array<Maybe<Metric>>>;
};
export declare type TeamMembersArgs = {
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<TeamMemberOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type TeamSavedQueriesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<SavedQueryStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<SavedQueryOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type TeamMetricCollectionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricCollectionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type TeamMetricsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type TeamMember = {
    __typename?: 'TeamMember';
    id: Scalars['ID'];
    teamId: Scalars['Int'];
    organizationId: Scalars['Int'];
    userId: Scalars['Int'];
    isTeamAdmin: Scalars['Boolean'];
    joinedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    team?: Maybe<Team>;
    user?: Maybe<User>;
};
/** An enumeration. */
export declare enum TeamMemberOrderBy {
    TeamId = "TEAM_ID",
    IsTeamAdmin = "IS_TEAM_ADMIN",
    UserId = "USER_ID",
    JoinedAt = "JOINED_AT",
    TeamMemberOrganizationId = "TeamMember_ORGANIZATION_ID",
    TeamMemberId = "TeamMember_ID",
    UserOrganizationId = "User_ORGANIZATION_ID",
    Email = "EMAIL",
    UserName = "USER_NAME",
    DeactivatedAt = "DEACTIVATED_AT",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    PrimaryDashboardId = "PRIMARY_DASHBOARD_ID",
    Auth0Id = "AUTH0_ID",
    AvatarUrl = "AVATAR_URL"
}
export declare type Dashboard = {
    __typename?: 'Dashboard';
    id: Scalars['ID'];
    title: Scalars['String'];
    dashboardLayout: Scalars['String'];
    organizationId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    sections?: Maybe<Array<Maybe<DashboardSection>>>;
    user?: Maybe<Array<Maybe<User>>>;
    team?: Maybe<Array<Maybe<Team>>>;
};
export declare type DashboardSection = {
    __typename?: 'DashboardSection';
    id: Scalars['ID'];
    dashboardId: Scalars['Int'];
    dashboardSectionType: Scalars['String'];
    items?: Maybe<Array<Maybe<DashboardItem>>>;
    dashboard?: Maybe<Dashboard>;
};
export declare type DashboardItem = {
    __typename?: 'DashboardItem';
    id: Scalars['ID'];
    dashboardSectionId: Scalars['Int'];
    dashboardRenderableType: Scalars['String'];
    title?: Maybe<Scalars['String']>;
    subtitle?: Maybe<Scalars['String']>;
    userId?: Maybe<Scalars['Int']>;
    teamId?: Maybe<Scalars['Int']>;
    metricId?: Maybe<Scalars['Int']>;
    metricCollectionId?: Maybe<Scalars['Int']>;
    position?: Maybe<Scalars['Int']>;
    dashboardSection?: Maybe<DashboardSection>;
    metricCollection?: Maybe<MetricCollection>;
    team?: Maybe<Team>;
    user?: Maybe<User>;
};
export declare type MetricCollection = {
    __typename?: 'MetricCollection';
    id: Scalars['ID'];
    title: Scalars['String'];
    organizationId: Scalars['Int'];
    primaryDashboardId?: Maybe<Scalars['Int']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
    slug: Scalars['String'];
    createdBy: Scalars['Int'];
    ownerTeamId?: Maybe<Scalars['Int']>;
    description?: Maybe<Scalars['String']>;
    defaultEmphasis?: Maybe<Scalars['Int']>;
    createdByUser?: Maybe<User>;
    organization?: Maybe<Organization>;
    teamOwner?: Maybe<Team>;
    primaryDashboard?: Maybe<Dashboard>;
    views?: Maybe<Array<Maybe<MetricCollectionView>>>;
    items?: Maybe<Array<Maybe<MetricCollectionMetric>>>;
    collectionItems?: Maybe<Array<Maybe<CollectionItem>>>;
    totalItems?: Maybe<Scalars['Int']>;
    totalRecentViews?: Maybe<Scalars['Int']>;
    totalRecentViewsForUser?: Maybe<Scalars['Int']>;
    userCanEdit?: Maybe<Scalars['Boolean']>;
};
export declare type MetricCollectionItemsArgs = {
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionMetricOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricCollectionCollectionItemsArgs = {
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricCollectionMetricOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricCollectionView = {
    __typename?: 'MetricCollectionView';
    id: Scalars['ID'];
    metricCollectionId: Scalars['Int'];
    userId: Scalars['Int'];
    organizationId: Scalars['Int'];
    createdAt: Scalars['DateTime'];
    metricCollection?: Maybe<MetricCollection>;
    organization?: Maybe<Organization>;
    user?: Maybe<User>;
};
export declare type MetricCollectionMetric = {
    __typename?: 'MetricCollectionMetric';
    id: Scalars['ID'];
    createdAt: Scalars['DateTime'];
    updatedAt: Scalars['DateTime'];
    metricCollectionId: Scalars['Int'];
    metricId?: Maybe<Scalars['Int']>;
    savedQueryId?: Maybe<Scalars['Int']>;
    position: Scalars['Int'];
    emphasis: Scalars['Int'];
    metricCollection?: Maybe<MetricCollection>;
    orgMetric?: Maybe<OrgMetric>;
    savedQuery?: Maybe<SavedQuery>;
    metric?: Maybe<Metric>;
};
export declare type OrgMetric = {
    __typename?: 'OrgMetric';
    id: Scalars['ID'];
    createdAt: Scalars['DateTime'];
    organizationId: Scalars['Int'];
    name: Scalars['String'];
    userOwners?: Maybe<Array<Maybe<MetricUserOwner>>>;
    teamOwners?: Maybe<Array<Maybe<MetricTeamOwner>>>;
    versions?: Maybe<Array<Maybe<Metric>>>;
    metricAnnotations?: Maybe<Array<Maybe<MetricAnnotation>>>;
    organization?: Maybe<Organization>;
};
export declare type MetricUserOwner = {
    __typename?: 'MetricUserOwner';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    orgMetricId: Scalars['Int'];
    userId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    isLocked: Scalars['Boolean'];
    user?: Maybe<User>;
    organization?: Maybe<Organization>;
};
export declare type MetricTeamOwner = {
    __typename?: 'MetricTeamOwner';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    teamId: Scalars['Int'];
    createdTs?: Maybe<Scalars['Int']>;
    orgMetricId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    team?: Maybe<Team>;
    organization?: Maybe<Organization>;
};
export declare type Metric = {
    __typename?: 'Metric';
    metadata_: Scalars['JSONString'];
    id?: Maybe<Scalars['Int']>;
    displayName?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    tier?: Maybe<Scalars['Int']>;
    metricType: Scalars['Int'];
    metricId: Scalars['Int'];
    params?: Maybe<Scalars['GenericScalar']>;
    createdAt: Scalars['DateTime'];
    hash: Scalars['String'];
    organizationId: Scalars['Int'];
    sourceDataSourceVersions: Scalars['JSONString'];
    orgDataSourceId?: Maybe<Scalars['Int']>;
    organization?: Maybe<Organization>;
    orgMetric?: Maybe<OrgMetric>;
    model?: Maybe<Array<Maybe<Model>>>;
    userOwners?: Maybe<Array<Maybe<MetricUserOwner>>>;
    teamOwners?: Maybe<Array<Maybe<MetricTeamOwner>>>;
    views?: Maybe<MetricView>;
    questions?: Maybe<Array<Maybe<Question>>>;
    resolvedQuestions?: Maybe<Question>;
    unresolvedQuestions?: Maybe<Question>;
    metadata?: Maybe<Scalars['GenericScalar']>;
    totalQuestions?: Maybe<Scalars['Int']>;
    totalAnnotations?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    isNew?: Maybe<Scalars['Boolean']>;
    valueFormat?: Maybe<Scalars['String']>;
    tierWithLock?: Maybe<LockableParameter>;
    displayNameWithLock?: Maybe<LockableParameter>;
    descriptionWithLock?: Maybe<LockableParameter>;
    valueFormatWithLock?: Maybe<LockableParameter>;
    latestApproval?: Maybe<MetricApproval>;
    annotations?: Maybe<Array<Maybe<Annotation>>>;
    currentDescription?: Maybe<Scalars['String']>;
    totalRecentViews?: Maybe<Scalars['Int']>;
    totalRecentViewsForUser?: Maybe<Scalars['Int']>;
    userIsMetricOwner?: Maybe<Scalars['Boolean']>;
    userCanEdit?: Maybe<Scalars['Boolean']>;
    dataSources?: Maybe<Array<Maybe<DataSourceVersion>>>;
    totalDataSources?: Maybe<Scalars['Int']>;
    savedQueries?: Maybe<Array<Maybe<SavedQuery>>>;
    totalSavedQueries?: Maybe<Scalars['Int']>;
    totalResolvedQuestions?: Maybe<Scalars['Int']>;
    totalUnresolvedQuestions?: Maybe<Scalars['Int']>;
    ownerTeams?: Maybe<Array<Maybe<Team>>>;
    totalOwnerTeams?: Maybe<Scalars['Int']>;
    ownerUsers?: Maybe<Array<Maybe<User>>>;
    totalOwnerUsers?: Maybe<Scalars['Int']>;
    tierTooltip?: Maybe<Scalars['String']>;
    isAdditive?: Maybe<Scalars['Boolean']>;
};
export declare type MetricQuestionsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<QuestionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<QuestionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricAnnotationsArgs = {
    dimensions?: Maybe<Array<Maybe<GMetricAnnotationDimensionInput>>>;
    startDate?: Maybe<Scalars['Date']>;
    endDate?: Maybe<Scalars['Date']>;
    priorities?: Maybe<Array<Maybe<Priority>>>;
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<AnnotationStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<AnnotationOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricDataSourcesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<DataSourceVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<DataSourceVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricSavedQueriesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<SavedQueryStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<SavedQueryOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricOwnerTeamsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<TeamStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<TeamOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type MetricOwnerUsersArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<UserStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<UserOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type Model = {
    __typename?: 'Model';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    uploaderId: Scalars['Int'];
    createdAt: Scalars['DateTime'];
    gitRepo: Scalars['String'];
    gitBranch: Scalars['String'];
    gitCommit: Scalars['String'];
    gitIsDirty: Scalars['Boolean'];
    executionContext?: Maybe<Scalars['String']>;
    isCurrent: Scalars['Boolean'];
    uploader?: Maybe<User>;
    metrics?: Maybe<Array<Maybe<Metric>>>;
    modelDataSources?: Maybe<Array<Maybe<ModelDataSource>>>;
    organization?: Maybe<Organization>;
};
export declare type ModelDataSource = {
    __typename?: 'ModelDataSource';
    orgDataSourceId: Scalars['ID'];
    modelId: Scalars['ID'];
    dataSourceVersionId: Scalars['ID'];
    dataSourceVersion?: Maybe<DataSourceVersion>;
    model?: Maybe<Model>;
};
export declare type DataSourceVersion = {
    __typename?: 'DataSourceVersion';
    id: Scalars['ID'];
    name: Scalars['String'];
    description: Scalars['String'];
    owners?: Maybe<Scalars['JSONString']>;
    connection: Scalars['String'];
    sqlTable?: Maybe<Scalars['String']>;
    sqlQuery?: Maybe<Scalars['String']>;
    identifiers: Scalars['JSONString'];
    measures?: Maybe<Scalars['GenericScalar']>;
    dimensions: Scalars['JSONString'];
    dataSourceMetadata?: Maybe<Scalars['GenericScalar']>;
    mutability: Scalars['JSONString'];
    constraint?: Maybe<Scalars['JSONString']>;
    createdAt: Scalars['DateTime'];
    hash: Scalars['String'];
    organizationId: Scalars['Int'];
    organization?: Maybe<Organization>;
};
export declare type MetricView = {
    __typename?: 'MetricView';
    organizationId: Scalars['Int'];
    userId: Scalars['ID'];
    metricId: Scalars['ID'];
    createdAt: Scalars['DateTime'];
    organization?: Maybe<Organization>;
};
export declare type Question = {
    __typename?: 'Question';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    authorId: Scalars['Int'];
    resolved?: Maybe<Scalars['Boolean']>;
    resolvedBy?: Maybe<Scalars['Int']>;
    resolvedAt?: Maybe<Scalars['DateTime']>;
    text: Scalars['String'];
    priority: Scalars['String'];
    notifiedAt?: Maybe<Scalars['DateTime']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    metricId: Scalars['Int'];
    organization?: Maybe<Organization>;
    replies?: Maybe<Array<Maybe<QuestionReply>>>;
    orgMetric?: Maybe<OrgMetric>;
    author?: Maybe<User>;
    resolvedByUser?: Maybe<User>;
    directedToUsers?: Maybe<Array<Maybe<User>>>;
    directedToTeams?: Maybe<Array<Maybe<Team>>>;
    totalLikes?: Maybe<Scalars['Int']>;
    likedByCurrentUser?: Maybe<Scalars['Boolean']>;
    totalReplies?: Maybe<Scalars['Int']>;
    currentUserIsAuthor?: Maybe<Scalars['Boolean']>;
    metricName?: Maybe<Scalars['String']>;
    userCanEdit?: Maybe<Scalars['Boolean']>;
    metric?: Maybe<Metric>;
};
export declare type QuestionRepliesArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<QuestionReplyStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<QuestionReplyOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type QuestionReply = {
    __typename?: 'QuestionReply';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    questionId: Scalars['Int'];
    authorId: Scalars['Int'];
    text: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    author?: Maybe<User>;
    question?: Maybe<Question>;
    likedByCurrentUser?: Maybe<Scalars['Boolean']>;
    totalLikes?: Maybe<Scalars['Int']>;
};
/** An enumeration. */
export declare enum QuestionReplyStrColumns {
    Text = "TEXT"
}
/** An enumeration. */
export declare enum QuestionReplyOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Text = "TEXT",
    AuthorId = "AUTHOR_ID",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    QuestionId = "QUESTION_ID"
}
/** An enumeration. */
export declare enum QuestionStrColumns {
    Priority = "PRIORITY",
    Text = "TEXT"
}
/** An enumeration. */
export declare enum QuestionOrderBy {
    ResolvedAt = "RESOLVED_AT",
    OrganizationId = "ORGANIZATION_ID",
    Text = "TEXT",
    AuthorId = "AUTHOR_ID",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    MetricId = "METRIC_ID",
    Id = "ID",
    Priority = "PRIORITY",
    NotifiedAt = "NOTIFIED_AT",
    ResolvedBy = "RESOLVED_BY",
    Resolved = "RESOLVED"
}
export declare type LockableParameter = {
    __typename?: 'LockableParameter';
    isLocked?: Maybe<Scalars['Boolean']>;
    value?: Maybe<Scalars['GenericScalar']>;
};
export declare type MetricApproval = {
    __typename?: 'MetricApproval';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    approverId: Scalars['Int'];
    approvedAt?: Maybe<Scalars['DateTime']>;
    metricId: Scalars['Int'];
    approver?: Maybe<User>;
    organization?: Maybe<Organization>;
};
export declare type Annotation = {
    __typename?: 'Annotation';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    authorId: Scalars['Int'];
    title: Scalars['String'];
    text: Scalars['String'];
    expectedImpact: Scalars['String'];
    priority: Scalars['String'];
    dateStartedAt: Scalars['String'];
    dateEndedAt: Scalars['String'];
    notifiedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    orgMetrics?: Maybe<Array<Maybe<OrgMetric>>>;
    author?: Maybe<User>;
    organization?: Maybe<Organization>;
    metricAnnotations?: Maybe<Array<Maybe<MetricAnnotation>>>;
    userCanEdit?: Maybe<Scalars['Boolean']>;
    metrics?: Maybe<Array<Maybe<Metric>>>;
};
export declare type MetricAnnotation = {
    __typename?: 'MetricAnnotation';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    annotationId: Scalars['Int'];
    metricId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    organization?: Maybe<Organization>;
    annotation?: Maybe<Annotation>;
    orgMetric?: Maybe<OrgMetric>;
    dimensions?: Maybe<Array<Maybe<MetricAnnotationDimension>>>;
    metric?: Maybe<Metric>;
};
export declare type MetricAnnotationDimension = {
    __typename?: 'MetricAnnotationDimension';
    id: Scalars['ID'];
    metricAnnotationId: Scalars['Int'];
    dimensionName: Scalars['String'];
    valueHashes?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type GMetricAnnotationDimensionInput = {
    dimensionName: Scalars['String'];
    valueHashes?: Maybe<Array<Maybe<Scalars['String']>>>;
};
/** An enumeration. */
export declare enum Priority {
    NoPriority = "NO_PRIORITY",
    Low = "LOW",
    Medium = "MEDIUM",
    High = "HIGH",
    Critical = "CRITICAL"
}
/** An enumeration. */
export declare enum AnnotationStrColumns {
    Priority = "PRIORITY",
    ExpectedImpact = "EXPECTED_IMPACT",
    Text = "TEXT",
    Title = "TITLE"
}
/** An enumeration. */
export declare enum AnnotationOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Text = "TEXT",
    DateEndedAt = "DATE_ENDED_AT",
    AuthorId = "AUTHOR_ID",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    Priority = "PRIORITY",
    ExpectedImpact = "EXPECTED_IMPACT",
    DeletedAt = "DELETED_AT",
    NotifiedAt = "NOTIFIED_AT",
    DateStartedAt = "DATE_STARTED_AT",
    Title = "TITLE"
}
/** An enumeration. */
export declare enum DataSourceVersionStrColumns {
    SqlQuery = "SQL_QUERY",
    Name = "NAME",
    Description = "DESCRIPTION",
    Hash = "HASH",
    Connection = "CONNECTION",
    SqlTable = "SQL_TABLE"
}
/** An enumeration. */
export declare enum DataSourceVersionOrderBy {
    Constraint = "CONSTRAINT",
    Hash = "HASH",
    Connection = "CONNECTION",
    CreatedAt = "CREATED_AT",
    Identifiers = "IDENTIFIERS",
    Id = "ID",
    Measures = "MEASURES",
    DataSourceMetadata = "DATA_SOURCE_METADATA",
    SqlTable = "SQL_TABLE",
    OrganizationId = "ORGANIZATION_ID",
    Name = "NAME",
    Description = "DESCRIPTION",
    Mutability = "MUTABILITY",
    SqlQuery = "SQL_QUERY",
    Dimensions = "DIMENSIONS",
    Owners = "OWNERS"
}
export declare type SavedQuery = {
    __typename?: 'SavedQuery';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    title: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    deletedAt?: Maybe<Scalars['DateTime']>;
    createdBy: Scalars['Int'];
    ownerTeamId?: Maybe<Scalars['Int']>;
    serializedQuery?: Maybe<Scalars['GenericScalar']>;
    createdByUser?: Maybe<User>;
    organization?: Maybe<Organization>;
    ownerTeam?: Maybe<Team>;
    orgMetrics?: Maybe<Array<Maybe<OrgMetric>>>;
    totalMetrics?: Maybe<Scalars['Int']>;
    metrics?: Maybe<Array<Maybe<Metric>>>;
};
export declare type SavedQueryMetricsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<MetricVersionStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<MetricVersionOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
/** An enumeration. */
export declare enum MetricVersionStrColumns {
    DisplayName = "DISPLAY_NAME",
    Hash = "HASH",
    Description = "DESCRIPTION",
    ValueFormat = "VALUE_FORMAT"
}
/** An enumeration. */
export declare enum MetricVersionOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    MetricType = "METRIC_TYPE",
    Description = "DESCRIPTION",
    Metadata = "METADATA",
    Hash = "HASH",
    SourceDataSourceVersions = "SOURCE_DATA_SOURCE_VERSIONS",
    Views = "VIEWS",
    Id = "ID",
    DisplayName = "DISPLAY_NAME",
    Params = "PARAMS",
    Tier = "TIER",
    OrgDataSourceId = "ORG_DATA_SOURCE_ID",
    MetricVersionCreatedAt = "MetricVersion_CREATED_AT",
    MetricVersionMetricId = "MetricVersion_METRIC_ID",
    MetricMetadataCreatedAt = "MetricMetadata_CREATED_AT",
    MetricMetadataMetricId = "MetricMetadata_METRIC_ID",
    DisplayNameLock = "DISPLAY_NAME_LOCK",
    UpdatedAt = "UPDATED_AT",
    ValueFormatLock = "VALUE_FORMAT_LOCK",
    ExtraFields = "EXTRA_FIELDS",
    CreatedBy = "CREATED_BY",
    UpdatedBy = "UPDATED_BY",
    ValueFormat = "VALUE_FORMAT",
    IsNew = "IS_NEW",
    DescriptionLock = "DESCRIPTION_LOCK",
    TierLock = "TIER_LOCK"
}
/** An enumeration. */
export declare enum SavedQueryStrColumns {
    Title = "TITLE"
}
/** An enumeration. */
export declare enum SavedQueryOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    SerializedQuery = "SERIALIZED_QUERY",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    DeletedAt = "DELETED_AT",
    OwnerTeamId = "OWNER_TEAM_ID",
    CreatedBy = "CREATED_BY",
    Title = "TITLE"
}
/** An enumeration. */
export declare enum TeamStrColumns {
    Slug = "SLUG",
    Name = "NAME",
    Theme = "THEME",
    Description = "DESCRIPTION"
}
/** An enumeration. */
export declare enum TeamOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Name = "NAME",
    Description = "DESCRIPTION",
    Views = "VIEWS",
    FeaturedMetricCollectionId = "FEATURED_METRIC_COLLECTION_ID",
    UpdatedAt = "UPDATED_AT",
    DeactivatedAt = "DEACTIVATED_AT",
    Theme = "THEME",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    PrimaryDashboardId = "PRIMARY_DASHBOARD_ID",
    Slug = "SLUG",
    CreatedBy = "CREATED_BY"
}
/** An enumeration. */
export declare enum UserStrColumns {
    Auth0Id = "AUTH0_ID",
    Email = "EMAIL",
    AvatarUrl = "AVATAR_URL",
    UserName = "USER_NAME"
}
/** An enumeration. */
export declare enum UserOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Email = "EMAIL",
    UserName = "USER_NAME",
    UpdatedAt = "UPDATED_AT",
    DeactivatedAt = "DEACTIVATED_AT",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    PrimaryDashboardId = "PRIMARY_DASHBOARD_ID",
    Auth0Id = "AUTH0_ID",
    AvatarUrl = "AVATAR_URL"
}
/** An enumeration. */
export declare enum MetricCollectionMetricOrderBy {
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    MetricId = "METRIC_ID",
    MetricCollectionId = "METRIC_COLLECTION_ID",
    Id = "ID",
    Position = "POSITION",
    SavedQueryId = "SAVED_QUERY_ID",
    Emphasis = "EMPHASIS"
}
export declare type CollectionItem = {
    __typename?: 'CollectionItem';
    id: Scalars['ID'];
    createdAt: Scalars['DateTime'];
    updatedAt: Scalars['DateTime'];
    metricCollectionId: Scalars['Int'];
    metricId?: Maybe<Scalars['Int']>;
    savedQueryId?: Maybe<Scalars['Int']>;
    position: Scalars['Int'];
    emphasis: Scalars['Int'];
    metricCollection?: Maybe<MetricCollection>;
    orgMetric?: Maybe<OrgMetric>;
    savedQuery?: Maybe<SavedQuery>;
    inCurrentModel?: Maybe<Scalars['Boolean']>;
    metric?: Maybe<Metric>;
};
export declare type TeamView = {
    __typename?: 'TeamView';
    id: Scalars['ID'];
    teamId: Scalars['Int'];
    userId: Scalars['Int'];
    organizationId: Scalars['Int'];
    createdAt: Scalars['DateTime'];
    organization?: Maybe<Organization>;
    team?: Maybe<Team>;
    user?: Maybe<User>;
};
/** An enumeration. */
export declare enum MetricCollectionStrColumns {
    Slug = "SLUG",
    Description = "DESCRIPTION",
    Title = "TITLE"
}
/** An enumeration. */
export declare enum MetricCollectionOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Description = "DESCRIPTION",
    Views = "VIEWS",
    UpdatedAt = "UPDATED_AT",
    DefaultEmphasis = "DEFAULT_EMPHASIS",
    CreatedAt = "CREATED_AT",
    Id = "ID",
    DeletedAt = "DELETED_AT",
    PrimaryDashboardId = "PRIMARY_DASHBOARD_ID",
    OwnerTeamId = "OWNER_TEAM_ID",
    Slug = "SLUG",
    CreatedBy = "CREATED_BY",
    Title = "TITLE"
}
export declare type ApiKey = {
    __typename?: 'ApiKey';
    prefix: Scalars['String'];
    organizationId: Scalars['Int'];
    userId: Scalars['Int'];
    type: Scalars['String'];
    secretHash: Scalars['String'];
    createdAt?: Maybe<Scalars['DateTime']>;
    revokedAt?: Maybe<Scalars['DateTime']>;
    revokerId?: Maybe<Scalars['Int']>;
    lastUsedAt?: Maybe<Scalars['DateTime']>;
    scope?: Maybe<Scalars['String']>;
    user?: Maybe<User>;
    organization?: Maybe<Organization>;
    revoker?: Maybe<User>;
};
/** An enumeration. */
export declare enum ApiKeyStrColumns {
    SecretHash = "SECRET_HASH",
    Prefix = "PREFIX",
    Type = "TYPE",
    Scope = "SCOPE"
}
/** An enumeration. */
export declare enum ApiKeyOrderBy {
    LastUsedAt = "LAST_USED_AT",
    OrganizationId = "ORGANIZATION_ID",
    UserId = "USER_ID",
    SecretHash = "SECRET_HASH",
    CreatedAt = "CREATED_AT",
    Scope = "SCOPE",
    RevokerId = "REVOKER_ID",
    Type = "TYPE",
    Prefix = "PREFIX",
    RevokedAt = "REVOKED_AT"
}
export declare type Feature = {
    __typename?: 'Feature';
    id: Scalars['ID'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    name: Scalars['String'];
    retiredAt?: Maybe<Scalars['DateTime']>;
    organizations?: Maybe<Array<Maybe<Organization>>>;
    users?: Maybe<Array<Maybe<User>>>;
    totalOrganizations?: Maybe<Scalars['Int']>;
    totalUsers?: Maybe<Scalars['Int']>;
};
export declare type FeatureOrganizationsArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<OrganizationStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<OrganizationOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
export declare type FeatureUsersArgs = {
    searchStr?: Maybe<Scalars['String']>;
    searchColumns?: Maybe<Array<Maybe<UserStrColumns>>>;
    pageNumber?: Maybe<Scalars['Int']>;
    pageSize?: Maybe<Scalars['Int']>;
    orderBy?: Maybe<UserOrderBy>;
    desc?: Maybe<Scalars['Boolean']>;
};
/** An enumeration. */
export declare enum OrganizationStrColumns {
    SourceControlUrl = "SOURCE_CONTROL_URL",
    Name = "NAME",
    PrimaryConfigRepo = "PRIMARY_CONFIG_REPO",
    MqlServerLogs = "MQL_SERVER_LOGS",
    PrimaryConfigBranch = "PRIMARY_CONFIG_BRANCH",
    LogoUrl = "LOGO_URL"
}
/** An enumeration. */
export declare enum OrganizationOrderBy {
    Name = "NAME",
    UpdatedAt = "UPDATED_AT",
    DeactivatedAt = "DEACTIVATED_AT",
    CreatedAt = "CREATED_AT",
    PrimaryConfigBranch = "PRIMARY_CONFIG_BRANCH",
    Id = "ID",
    LogoUrl = "LOGO_URL",
    PrimaryConfigRepo = "PRIMARY_CONFIG_REPO",
    IsHosted = "IS_HOSTED",
    Type = "TYPE",
    MqlServerLogs = "MQL_SERVER_LOGS",
    SourceControlUrl = "SOURCE_CONTROL_URL"
}
export declare type OrgMqlServer = {
    __typename?: 'OrgMqlServer';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    updatedAt?: Maybe<Scalars['DateTime']>;
    name: Scalars['String'];
    url: Scalars['String'];
    isOrgDefault?: Maybe<Scalars['Boolean']>;
    configSecret?: Maybe<Scalars['String']>;
    dwEngine?: Maybe<DwEngine>;
    heartbeats?: Maybe<Array<Maybe<MqlHeartbeat>>>;
    organization?: Maybe<Organization>;
    latestHeartbeat?: Maybe<MqlHeartbeat>;
};
/** An enumeration. */
export declare enum DwEngine {
    PrestoHive = "PRESTO_HIVE",
    Redshift = "REDSHIFT",
    Postgresql = "POSTGRESQL",
    Livy = "LIVY",
    Mysql = "MYSQL",
    Snowflake = "SNOWFLAKE",
    Databricks = "DATABRICKS",
    Athena = "ATHENA"
}
export declare type MqlHeartbeat = {
    __typename?: 'MqlHeartbeat';
    id: Scalars['ID'];
    organizationId: Scalars['Int'];
    userId: Scalars['Int'];
    createdAt?: Maybe<Scalars['DateTime']>;
    versionSha: Scalars['String'];
    status: Scalars['String'];
    details?: Maybe<Scalars['JSONString']>;
    mqlServerId?: Maybe<Scalars['Int']>;
    mqlServer?: Maybe<OrgMqlServer>;
    user?: Maybe<User>;
    org?: Maybe<Organization>;
};
/** An enumeration. */
export declare enum OrgMqlServerStrColumns {
    Url = "URL",
    Name = "NAME",
    ConfigSecret = "CONFIG_SECRET"
}
/** An enumeration. */
export declare enum OrgMqlServerOrderBy {
    OrganizationId = "ORGANIZATION_ID",
    Name = "NAME",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    IsOrgDefault = "IS_ORG_DEFAULT",
    Id = "ID",
    ConfigSecret = "CONFIG_SECRET",
    DwEngine = "DW_ENGINE",
    Url = "URL"
}
/** An enumeration. */
export declare enum MetricTier {
    One = "ONE",
    Two = "TWO",
    Three = "THREE"
}
/** An enumeration. */
export declare enum MetricType {
    MeasureProxy = "MEASURE_PROXY",
    Ratio = "RATIO",
    Expr = "EXPR",
    Cumulative = "CUMULATIVE"
}
/** An enumeration. */
export declare enum FeatureStrColumns {
    Name = "NAME"
}
/** An enumeration. */
export declare enum FeatureOrderBy {
    RetiredAt = "RETIRED_AT",
    Name = "NAME",
    UpdatedAt = "UPDATED_AT",
    CreatedAt = "CREATED_AT",
    Id = "ID"
}
/** Wrapper to contain queries related to transform settings & configs. */
export declare type TransformConfig = {
    __typename?: 'TransformConfig';
    auth0IdleSessionLifetimeHours?: Maybe<Scalars['Int']>;
    latestTermsOfService?: Maybe<TermsOfServiceVersion>;
};
export declare type TermsOfServiceVersion = {
    __typename?: 'TermsOfServiceVersion';
    id: Scalars['ID'];
    pdfUrl: Scalars['String'];
    createdAt: Scalars['DateTime'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type Mutation = {
    __typename?: 'Mutation';
    revokeApiKeyTest?: Maybe<ApiKey>;
    createOrganizationTest?: Maybe<Organization>;
    logMqlLog?: Maybe<LogMqlLogs>;
    setOrgMqlServerConfigSecret?: Maybe<SetOrgMqlServerConfigSecretId>;
    sendMqlHeartbeat?: Maybe<SendMqlHeartbeat>;
    createAnnotationTest?: Maybe<CreateAnnotation>;
    updateAnnotationTest?: Maybe<UpdateAnnotation>;
    removeAnnotation?: Maybe<RemoveAnnotation>;
    /** Update user's email in DB and auth0. Auth0 needs to match for user to login with new email. */
    updateUserEmail?: Maybe<UpdateUserEmail>;
    /** Create API Key for given user. If no user_id passed, create key for authenticated user. */
    createApiKeyTest?: Maybe<CreateApiKey>;
    /** Create User for given org. If no org_id passed, create user in org of authenticated user. */
    createUserTest?: Maybe<CreateUser>;
    /** Add role to user in DB and Auth0. */
    addRoleToUserTest?: Maybe<AddRoleToUser>;
    /** Remove role from user in DB and Auth0. */
    removeRoleFromUserTest?: Maybe<RemoveRoleFromUser>;
    /** Deactivate user in DB and Auth0. */
    deactivateUserTest?: Maybe<DeactivateUser>;
    /** Reactivate user in DB and Auth0. */
    reactivateUserTest?: Maybe<ReactivateUser>;
    /** Update fields on a User. */
    updateUserTest?: Maybe<UpdateUser>;
    setUserPreference?: Maybe<SetUserPreference>;
    /** Stores hosted MQL Server config using AWS Secrets Manager. */
    updateMqlServerConfig?: Maybe<UpdateMqlServerConfig>;
    /** Removes hosted MQL Server config using AWS Secrets Manager. */
    revokeMqlServerConfig?: Maybe<RevokeMqlServerConfig>;
    featuresCreate?: Maybe<Feature>;
    featuresUpdate?: Maybe<Feature>;
    featuresAddOrgs?: Maybe<Feature>;
    featuresAddUsers?: Maybe<Feature>;
    featuresRemoveAccess?: Maybe<Feature>;
    questionsCreateReply?: Maybe<Question>;
    questionRepliesLike?: Maybe<QuestionReply>;
    questionsLike?: Maybe<Question>;
    questionRepliesUnlike?: Maybe<QuestionReply>;
    questionsUnlike?: Maybe<Question>;
    questionsCreate?: Maybe<Question>;
    questionsDelete?: Maybe<Question>;
    questionsEdit?: Maybe<Question>;
    metricCollectionCreate?: Maybe<MetricCollection>;
    metricCollectionUpdate?: Maybe<MetricCollection>;
    metricCollectionDelete?: Maybe<MetricCollection>;
    orgMqlServerUpdate?: Maybe<OrgMqlServer>;
    orgMqlServerDelete?: Maybe<OrgMqlServer>;
    orgMqlServerCreate?: Maybe<OrgMqlServer>;
    teamsCreate?: Maybe<Team>;
    teamsUpdate?: Maybe<Team>;
    teamsAddMember?: Maybe<Team>;
    teamsRemoveMember?: Maybe<Team>;
    teamSetMemberAdminStatus?: Maybe<Team>;
    teamsAssignAsMetricOwner?: Maybe<Team>;
    teamsRemoveAsMetricOwner?: Maybe<Team>;
    organizationsUpdate?: Maybe<Organization>;
    organizationsSetTierTooltip?: Maybe<Organization>;
    organizationsSetMfaPrefs?: Maybe<Organization>;
    organizationsSetAllowedEmailDomains?: Maybe<Organization>;
    organizationsDelete?: Maybe<Organization>;
    metricsApprove?: Maybe<Metric>;
    metricsLogView?: Maybe<MetricView>;
    metricCollectionsLogView?: Maybe<MetricCollectionView>;
    teamsLogView?: Maybe<TeamView>;
    metricsAddUserOwners?: Maybe<Metric>;
    metricsRemoveUserOwners?: Maybe<Metric>;
    metricsAssignTeamOwners?: Maybe<Metric>;
    metricsRemoveTeamOwners?: Maybe<Metric>;
    metricsAddDescription?: Maybe<Metric>;
    metricsUpdateMetadata?: Maybe<Metric>;
    savedQueryCreate?: Maybe<SavedQuery>;
    savedQueryUpdate?: Maybe<SavedQuery>;
    savedQueryDeactivate?: Maybe<SavedQuery>;
    sendInvites?: Maybe<Organization>;
    acceptTermsOfService?: Maybe<User>;
    createTermsOfService?: Maybe<TermsOfServiceVersion>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationRevokeApiKeyTestArgs = {
    prefix: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationCreateOrganizationTestArgs = {
    name: Scalars['String'];
    primaryConfigRepo?: Maybe<Scalars['String']>;
    primaryConfigBranch?: Maybe<Scalars['String']>;
    mqlServerUrl?: Maybe<Scalars['String']>;
    sourceControlUrl?: Maybe<Scalars['String']>;
    mqlServerLogs?: Maybe<Scalars['String']>;
    isHosted?: Maybe<Scalars['Boolean']>;
    dwEngine?: Maybe<Scalars['String']>;
    mqlServerName?: Maybe<Scalars['String']>;
    requireMfa?: Maybe<Scalars['Boolean']>;
    allowMfaRememberBrowser?: Maybe<Scalars['Boolean']>;
    allowedEmailDomains?: Maybe<Array<Maybe<Scalars['String']>>>;
    orgType?: Maybe<GOrgType>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationLogMqlLogArgs = {
    level?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    tags?: Maybe<Array<Scalars['String']>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSetOrgMqlServerConfigSecretArgs = {
    clientConfigSecretId?: Maybe<Scalars['String']>;
    mqlServerId?: Maybe<Scalars['Int']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSendMqlHeartbeatArgs = {
    mqlServerId?: Maybe<Scalars['Int']>;
    sha: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationCreateAnnotationTestArgs = {
    dateEndedAt: Scalars['Date'];
    dateStartedAt: Scalars['Date'];
    expectedImpact: Scalars['String'];
    metricInputs: Array<Maybe<GMetricAnnotationInput>>;
    priority: Priority;
    text: Scalars['String'];
    title: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationUpdateAnnotationTestArgs = {
    annotationId: Scalars['Int'];
    dateEndedAt?: Maybe<Scalars['Date']>;
    dateStartedAt?: Maybe<Scalars['Date']>;
    expectedImpact?: Maybe<Scalars['String']>;
    metricInputs?: Maybe<Array<Maybe<GMetricAnnotationInput>>>;
    priority?: Maybe<Priority>;
    text?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationRemoveAnnotationArgs = {
    annotationId: Scalars['Int'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationUpdateUserEmailArgs = {
    email: Scalars['String'];
    userId?: Maybe<Scalars['Int']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationCreateApiKeyTestArgs = {
    userId?: Maybe<Scalars['Int']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationCreateUserTestArgs = {
    email: Scalars['String'];
    isOrgOwner?: Maybe<Scalars['Boolean']>;
    organizationId?: Maybe<Scalars['Int']>;
    userName: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationAddRoleToUserTestArgs = {
    role: Scalars['String'];
    userId: Scalars['Int'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationRemoveRoleFromUserTestArgs = {
    role: Scalars['String'];
    userId: Scalars['Int'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationDeactivateUserTestArgs = {
    userId: Scalars['Int'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationReactivateUserTestArgs = {
    userId: Scalars['Int'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationUpdateUserTestArgs = {
    avatarUrl?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    primaryDashboardId?: Maybe<Scalars['ID']>;
    userName?: Maybe<Scalars['String']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSetUserPreferenceArgs = {
    prefKey: Scalars['String'];
    prefValue: Scalars['String'];
    userId?: Maybe<Scalars['ID']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationUpdateMqlServerConfigArgs = {
    dwPassword?: Maybe<Scalars['String']>;
    modeCreds?: Maybe<Scalars['String']>;
    mqlServerId?: Maybe<Scalars['Int']>;
    tfdApiKey?: Maybe<Scalars['String']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationRevokeMqlServerConfigArgs = {
    mqlServerId?: Maybe<Scalars['Int']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationFeaturesCreateArgs = {
    name: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationFeaturesUpdateArgs = {
    id: Scalars['ID'];
    name?: Maybe<Scalars['String']>;
    retireFeature?: Maybe<Scalars['Boolean']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationFeaturesAddOrgsArgs = {
    featureId: Scalars['ID'];
    organizationIds: Array<Maybe<Scalars['ID']>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationFeaturesAddUsersArgs = {
    featureId: Scalars['ID'];
    userIds: Array<Maybe<Scalars['ID']>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationFeaturesRemoveAccessArgs = {
    featureId: Scalars['ID'];
    userIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
    organizationIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsCreateReplyArgs = {
    questionId: Scalars['ID'];
    text: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionRepliesLikeArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsLikeArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionRepliesUnlikeArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsUnlikeArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsCreateArgs = {
    text: Scalars['String'];
    priority: Scalars['String'];
    metricId: Scalars['ID'];
    directedToUsers?: Maybe<Array<Maybe<Scalars['ID']>>>;
    directedToTeams?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsDeleteArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationQuestionsEditArgs = {
    id: Scalars['ID'];
    text?: Maybe<Scalars['String']>;
    priority?: Maybe<Scalars['String']>;
    directedToTeams?: Maybe<Array<Maybe<Scalars['ID']>>>;
    directedToUsers?: Maybe<Array<Maybe<Scalars['ID']>>>;
    resolved?: Maybe<Scalars['Boolean']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricCollectionCreateArgs = {
    title: Scalars['String'];
    description: Scalars['String'];
    slug: Scalars['String'];
    defaultEmphasis: Scalars['Int'];
    metrics?: Maybe<Array<Maybe<Scalars['ID']>>>;
    savedQueries?: Maybe<Array<Maybe<Scalars['ID']>>>;
    ownerTeamId?: Maybe<Scalars['ID']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricCollectionUpdateArgs = {
    id: Scalars['ID'];
    title?: Maybe<Scalars['String']>;
    primaryDashboardId?: Maybe<Scalars['ID']>;
    description?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    defaultEmphasis?: Maybe<Scalars['Int']>;
    items?: Maybe<Array<Maybe<MetricCollectionItem>>>;
    ownerTeamId?: Maybe<Scalars['ID']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricCollectionDeleteArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrgMqlServerUpdateArgs = {
    id: Scalars['ID'];
    name?: Maybe<Scalars['String']>;
    url?: Maybe<Scalars['String']>;
    isOrgDefault?: Maybe<Scalars['Boolean']>;
    configSecret?: Maybe<Scalars['String']>;
    dwEngine?: Maybe<Scalars['String']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrgMqlServerDeleteArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrgMqlServerCreateArgs = {
    organizationId?: Maybe<Scalars['ID']>;
    name: Scalars['String'];
    url: Scalars['String'];
    isOrgDefault?: Maybe<Scalars['Boolean']>;
    configSecret?: Maybe<Scalars['String']>;
    dwEngine?: Maybe<Scalars['String']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsCreateArgs = {
    name: Scalars['String'];
    slug: Scalars['String'];
    organizationId?: Maybe<Scalars['ID']>;
    description?: Maybe<Scalars['String']>;
    theme?: Maybe<Scalars['String']>;
    regularMemberUserIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
    teamAdminUserIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsUpdateArgs = {
    id: Scalars['ID'];
    name?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    theme?: Maybe<Scalars['String']>;
    primaryDashboardId?: Maybe<Scalars['Int']>;
    featuredMetricCollectionId?: Maybe<Scalars['Int']>;
    deactivate?: Maybe<Scalars['Boolean']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsAddMemberArgs = {
    teamId: Scalars['ID'];
    regularMemberUserIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
    teamAdminUserIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsRemoveMemberArgs = {
    teamId: Scalars['ID'];
    userId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamSetMemberAdminStatusArgs = {
    teamMemberId: Scalars['ID'];
    isTeamAdmin: Scalars['Boolean'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsAssignAsMetricOwnerArgs = {
    teamId: Scalars['ID'];
    metricIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsRemoveAsMetricOwnerArgs = {
    teamId: Scalars['ID'];
    metricIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrganizationsUpdateArgs = {
    id: Scalars['ID'];
    name?: Maybe<Scalars['String']>;
    logoUrl?: Maybe<Scalars['String']>;
    primaryConfigRepo?: Maybe<Scalars['String']>;
    primaryConfigBranch?: Maybe<Scalars['String']>;
    sourceControlUrl?: Maybe<Scalars['String']>;
    mqlServerLogs?: Maybe<Scalars['String']>;
    isHosted?: Maybe<Scalars['Boolean']>;
    orgType?: Maybe<GOrgType>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrganizationsSetTierTooltipArgs = {
    organizationId: Scalars['ID'];
    tooltip: Scalars['String'];
    tier: MetricTier;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrganizationsSetMfaPrefsArgs = {
    organizationId: Scalars['ID'];
    mfaPref: MfaPref;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrganizationsSetAllowedEmailDomainsArgs = {
    organizationId: Scalars['ID'];
    allowedEmailDomains: Array<Maybe<Scalars['String']>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationOrganizationsDeleteArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsApproveArgs = {
    metricId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsLogViewArgs = {
    metricId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricCollectionsLogViewArgs = {
    metricCollectionId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationTeamsLogViewArgs = {
    teamId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsAddUserOwnersArgs = {
    metricId: Scalars['ID'];
    userIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsRemoveUserOwnersArgs = {
    metricId: Scalars['ID'];
    userIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsAssignTeamOwnersArgs = {
    metricId: Scalars['ID'];
    teamIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsRemoveTeamOwnersArgs = {
    metricId: Scalars['ID'];
    teamIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsAddDescriptionArgs = {
    metricId: Scalars['ID'];
    description: Scalars['String'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationMetricsUpdateMetadataArgs = {
    metricId: Scalars['ID'];
    description?: Maybe<Scalars['String']>;
    tier?: Maybe<Scalars['Int']>;
    displayName?: Maybe<Scalars['String']>;
    valueFormat?: Maybe<Scalars['String']>;
    extraFields?: Maybe<Scalars['JSONString']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSavedQueryCreateArgs = {
    title: Scalars['String'];
    serializedQuery: Scalars['GenericScalar'];
    metricIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
    ownerTeamId?: Maybe<Scalars['ID']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSavedQueryUpdateArgs = {
    id: Scalars['ID'];
    title?: Maybe<Scalars['String']>;
    createdBy?: Maybe<Scalars['Int']>;
    ownerTeamId?: Maybe<Scalars['Int']>;
    serializedQuery?: Maybe<Scalars['GenericScalar']>;
    metricIds?: Maybe<Array<Maybe<Scalars['ID']>>>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSavedQueryDeactivateArgs = {
    id: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationSendInvitesArgs = {
    emails: Array<Maybe<Scalars['String']>>;
    organizationId?: Maybe<Scalars['ID']>;
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationAcceptTermsOfServiceArgs = {
    userId: Scalars['ID'];
    versionId: Scalars['ID'];
};
/**
 * Base mutation object exposed by GraphQL.
 *
 * Mutation names will be converted from snake_case to camelCase automatically
 * (e.g., log_mql_log will show up as logMqlLog in the GQL schema).
 */
export declare type MutationCreateTermsOfServiceArgs = {
    pdfUrl: Scalars['String'];
};
/** An enumeration. */
export declare enum GOrgType {
    Paid = "PAID",
    Trial = "TRIAL",
    Internal = "INTERNAL",
    Test = "TEST"
}
export declare type LogMqlLogs = {
    __typename?: 'LogMQLLogs';
    ok?: Maybe<Scalars['Boolean']>;
};
export declare type SetOrgMqlServerConfigSecretId = {
    __typename?: 'SetOrgMqlServerConfigSecretId';
    mqlServer?: Maybe<OrgMqlServer>;
};
export declare type SendMqlHeartbeat = {
    __typename?: 'SendMqlHeartbeat';
    success?: Maybe<Scalars['Boolean']>;
    heartbeat?: Maybe<MqlHeartbeat>;
};
export declare type CreateAnnotation = {
    __typename?: 'CreateAnnotation';
    annotation?: Maybe<Annotation>;
};
export declare type GMetricAnnotationInput = {
    metricId: Scalars['Int'];
    dimensions?: Maybe<Array<Maybe<GMetricAnnotationDimensionInput>>>;
};
export declare type UpdateAnnotation = {
    __typename?: 'UpdateAnnotation';
    annotation?: Maybe<Annotation>;
};
export declare type RemoveAnnotation = {
    __typename?: 'RemoveAnnotation';
    ok?: Maybe<Scalars['Boolean']>;
};
/** Update user's email in DB and auth0. Auth0 needs to match for user to login with new email. */
export declare type UpdateUserEmail = {
    __typename?: 'UpdateUserEmail';
    user?: Maybe<User>;
};
/** Create API Key for given user. If no user_id passed, create key for authenticated user. */
export declare type CreateApiKey = {
    __typename?: 'CreateApiKey';
    createdKeyFullString?: Maybe<Scalars['String']>;
    createdKeyPrefix?: Maybe<Scalars['String']>;
};
/** Create User for given org. If no org_id passed, create user in org of authenticated user. */
export declare type CreateUser = {
    __typename?: 'CreateUser';
    user?: Maybe<User>;
};
/** Add role to user in DB and Auth0. */
export declare type AddRoleToUser = {
    __typename?: 'AddRoleToUser';
    user?: Maybe<User>;
};
/** Remove role from user in DB and Auth0. */
export declare type RemoveRoleFromUser = {
    __typename?: 'RemoveRoleFromUser';
    user?: Maybe<User>;
};
/** Deactivate user in DB and Auth0. */
export declare type DeactivateUser = {
    __typename?: 'DeactivateUser';
    user?: Maybe<User>;
};
/** Reactivate user in DB and Auth0. */
export declare type ReactivateUser = {
    __typename?: 'ReactivateUser';
    user?: Maybe<User>;
};
/** Update fields on a User. */
export declare type UpdateUser = {
    __typename?: 'UpdateUser';
    user?: Maybe<User>;
};
export declare type SetUserPreference = {
    __typename?: 'SetUserPreference';
    user?: Maybe<User>;
};
/** Stores hosted MQL Server config using AWS Secrets Manager. */
export declare type UpdateMqlServerConfig = {
    __typename?: 'UpdateMqlServerConfig';
    config?: Maybe<MqlServerConfig>;
};
/** MQL Server configuration for hosted MQL Servers */
export declare type MqlServerConfig = {
    __typename?: 'MqlServerConfig';
    /** MQL Server ID as stored in the Backend */
    mqlServerId?: Maybe<Scalars['Int']>;
    /** Transform Data API Key. _Note:_ Stored securely using AWS Secrets Manager. */
    tfdApiKey?: Maybe<Scalars['String']>;
    /** Password used to access the Data Warehouse. _Note:_ Stored securely using AWS Secrets Manager. */
    dwPassword?: Maybe<Scalars['String']>;
    /** Mode bridge connection config. _Note:_ Stored securely using AWS Secrets Manager. */
    modeCreds?: Maybe<Scalars['String']>;
};
/** Removes hosted MQL Server config using AWS Secrets Manager. */
export declare type RevokeMqlServerConfig = {
    __typename?: 'RevokeMqlServerConfig';
    success?: Maybe<Scalars['Boolean']>;
};
/** Graphene input object for a metric collection item. Essentially a dataclass. */
export declare type MetricCollectionItem = {
    metricId?: Maybe<Scalars['ID']>;
    savedQueryId?: Maybe<Scalars['ID']>;
    emphasis: Scalars['Int'];
    position: Scalars['Int'];
};
export declare type MfaPref = {
    requireMfa: Scalars['Boolean'];
    allowMfaRememberBrowser: Scalars['Boolean'];
};
export declare type SetMqlServerMutationVariables = Exact<{
    newServerIdAsString: Scalars['String'];
    userId: Scalars['ID'];
}>;
export declare type SetMqlServerMutation = ({
    __typename?: 'Mutation';
} & {
    setUserPreference?: Maybe<({
        __typename?: 'SetUserPreference';
    } & {
        user?: Maybe<({
            __typename?: 'User';
        } & {
            prefs?: Maybe<Array<Maybe<({
                __typename?: 'UserPref';
            } & Pick<UserPref, 'id' | 'prefKey' | 'prefValue' | 'userId' | 'createdAt'>)>>>;
        })>;
    })>;
});
